@@ -340,6 +340,9 @@ class AsyncLocalSubscriber(AsyncSubscriber):
     async def commit(self, task, *, timeout: float = None):
         self.uncommitted.remove(task.uuid)
 
+    async def rollback(self, task, *, timeout: float = None):
+        pass
+
     async def get(self, *, timeout: float = None):
         task = await super().get(timeout=timeout)
         self.uncommitted.add(task.uuid)
