@@ -40,7 +40,10 @@ class BetterprotoSerializer(BaseTaskSerializer):
             wrapper = BytesValue(value=payload)
             return 'google.protobuf.BytesValue', bytes(wrapper)
         else:
-            raise ValueError('unsupported payload type')
+            try:
+                return f'custom', bytes(payload)
+            except TypeError:
+                raise ValueError('unsupported payload type')
 
     @classmethod
     def _decode_payload(cls, payload):
@@ -52,6 +55,11 @@ class BetterprotoSerializer(BaseTaskSerializer):
             w = BytesValue()
             w.parse(payload.value)
             return w.value
+        elif payload.type_url == 'custom':
+            # actual decoding needs to be done on client code depending on actual transfer protocol and encoding
+            return payload.value
+        else:
+            raise ValueError(f'unsupported payload type: {payload.type_url}')
 
     def encode(self, task: Task) -> bytes:
 
